@@ -1,4 +1,4 @@
-# $Id: Exercise.pm 46 2007-06-01 20:51:28Z lembark $
+# $Id: Exercise.pm 47 2007-06-04 15:22:42Z lembark $
 #######################################################################
 # housekeeping
 #######################################################################
@@ -160,6 +160,9 @@ my %ref_handlerz =
         my $message = '';
         my $compare = '';
 
+        # no warnings avoids nastygrams about undef values
+        # in join.
+
         if
         (
             1 <= @$element
@@ -203,7 +206,9 @@ my %ref_handlerz =
         }
         elsif( $compare )
         {
-            $cmp_struct->( $result, $expect, $message )
+            'CODE' eq ref $expect 
+            ? $expect->( $obj, $result, $message )
+            : $cmp_struct->( $result, $expect, $message )
             and return;
 
             fail "Failed compare: $message" unless $noplan;
@@ -463,8 +468,8 @@ Object::Exercise - Generic execution & benchmark harness for method calls.
     ],
 
     [
-      [ qw( method expected to fail ) ]   # continue on failure
-      [],
+      [ qw( method expected to fail ) ]   
+      ''                                  # continue on failure
     ],
 
     [
